Module oxygengine_navigation::resource[][src]

Structs

Nav mesh area descriptor. Nav mesh area holds information about specific nav mesh triangle.

Nav mesh object used to find shortest path between two points.

ECS resource that holds and manages nav meshes.

Nav mesh triangle description - lists used vertices indices.

Enums

Error data.

Quality of finding path.

Quality of querying a point on nav mesh.

Type Definitions

Nav mash identifier.

Nav net identifier.

Result data.